@@ -58,7 +58,7 @@ struct yysvf {
 struct yysvf *yyestate;
 extern struct yysvf yysvec[], *yybgin;
 /*
- * Copyright (c) 1997-1998 Erez Zadok
+ * Copyright (c) 1997-2003 Erez Zadok
  * Copyright (c) 1989 Jan-Simon Pendry
  * Copyright (c) 1989 Imperial College of Science, Technology & Medicine
  * Copyright (c) 1989 The Regents of the University of California.
@@ -76,7 +76,7 @@ extern struct yysvf yysvec[], *yybgin;
  *    notice, this list of conditions and the following disclaimer in the
  *    documentation and/or other materials provided with the distribution.
  * 3. All advertising materials mentioning features or use of this software
- *    must display the following acknowledgement:
+ *    must display the following acknowledgment:
  *      This product includes software developed by the University of
  *      California, Berkeley and its contributors.
  * 4. Neither the name of the University nor the names of its contributors
@@ -95,9 +95,8 @@ extern struct yysvf yysvec[], *yybgin;
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- *	%W% (Berkeley) %G%
  *
- * $Id: conf_tok.l,v 5.2.2.1 1992/02/09 15:09:36 jsp beta $
+ * $Id$
  *
  */
 
@@ -128,16 +127,17 @@ extern struct yysvf yysvec[], *yybgin;
 #endif /* ECHO */
 
 /*
- * There are some things that need to be defined only if useing GNU flex.
+ * There are some things that need to be defined only if using GNU flex.
  * These must not be defined if using standard lex
  */
 #ifdef FLEX_SCANNER
 # ifndef ECHO
 #  define ECHO (void) fwrite( yytext, yyleng, 1, yyout )
 # endif /* not ECHO */
-int yylineno = 0;
 #endif /* FLEX_SCANNER */
 
+int ayylineno = 0;
+
 int yylex(void);
 /*
  * some systems such as DU-4.x have a different GNU flex in /usr/bin
@@ -151,15 +151,14 @@ int yywrap(void);
 #define TOK_DEBUG 0
 
 #if TOK_DEBUG
-# define dprintf(f,s) fprintf(stderr, (f), yylineno, (s))
+# define dprintf(f,s) fprintf(stderr, (f), ayylineno, (s))
 # define amu_return(v)
-#else
+#else /* not TOK_DEBUG */
 # define dprintf(f,s)
 # define amu_return(v) return((v))
-#endif /* TOK_DEBUG */
+#endif /* not TOK_DEBUG */
 
-/* no need to use yyunput() or yywrap() */
-#define YY_NO_UNPUT
+/* no need to use yywrap() */
 #define YY_SKIP_YYWRAP
 
 # define YYNEWLINE 10
@@ -171,7 +170,7 @@ case 0:
    if(yywrap()) return(0); break;
 case 1:
 		{
-			yylineno++;
+			ayylineno++;
 			amu_return(NEWLINE);
 			}
 break;
@@ -204,7 +203,7 @@ break;
 case 6:
 	{
 			/* a comment line includes the terminating \n */
-			yylineno++;
+			ayylineno++;
 			yytext[strlen((char *)yytext)-1] = '\0';
 			dprintf("%8d: Comment \"%s\"\n", yytext);
 			}
@@ -423,8 +422,7 @@ unsigned char yyextra[] = {
 0,0,0,0,0,0,0,0,
 0,0,0,0,0,0,0,0,
 0};
-/* @(#) A.11.00.00 HP C LANGUAGE TOOL (NCFORM) 
-*/
+/* @(#) A.11.01.00 HP C LANGUAGE TOOL (NCFORM) 980815 $      */
 #ifdef YYREENTRANT
 __thread int yylineno;
 #else
